@@ -340,8 +340,8 @@ class OFSMCCSolver:
         a = 340.8
         V_mach = p_data['V'] / a
         Km = np.interp(V_mach, mach, km) * 1e-3
-        theta_k = p_data['gun']['theta_k']
-        eta_k = round(np.pi / (np.tan(theta_k)))
+        eta_k = p_data['gun']['eta_k']
+
 
         d = p_data['gun']['d']
         fi = 0.57
@@ -527,7 +527,7 @@ class APFSDMccSolver(ABCSolver):
         S0 = np.pi * p_data['r_v'] ** 2
         V0 -= S0 * l_n / 3.
 
-        mass_center = p_data['l_n'] / 3.
+        mass_center = p_data['l_n'] * 2. / 3.
 
         mass = V0 * p_data['rho_b']
 
